<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>View Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <location filename="../mainwindow.cpp" line="487"/>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Select ISO</source>
        <translation>Wybierz ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wybierz docelowe urządzenie USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wybierz plik ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Advanced Options</source>
        <translation>Zaawansowane opcje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Utwórz system plików ext4, nawet jeśli taki istnieje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Zapisz oryginalny katalog rozruchowy podczas aktualizacji live-usb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Użyj partycjonowania gpt zamiast msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>GPT partitioning</source>
        <translation>Partycjonowanie GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Aktualizuj (aktualizuj tylko istniejący live-usb)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Nie zastępuj plików syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Keep syslinux files</source>
        <translation>Zachowaj pliki syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Ignore USB/removable check</source>
        <translation>Zignoruj sprawdzanie USB/pamięci przenośnej</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Temporarily disable automounting</source>
        <translation>Tymczasowo wyłącz automontowanie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Ustaw flagę dysku pmbr_boot (nie uruchomi się przez UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Nie używaj fuseiso do montowania plików iso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Rozmiar partycji ESP (uefi):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Verbosity (less to more):</source>
        <translation>Szczegółowość (mniej oznacza większą):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="513"/>
        <source>Make separate data partition (percent)</source>
        <translation>Utwórz osobną partycję danych (procent)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Refresh drive list</source>
        <translation>Odśwież listę napędów</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Show advanced options</source>
        <translation>Pokaż opcje zaawansowane</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation type="vanished">W pełni funkcjonalny - zapisywalny LiveUSB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="589"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Tylko do odczytu, nie można zapisywać danych korzystając z Persistence</translation>
    </message>
    <message>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation type="vanished">Tryb obrazu - LiveUSB tylko do odczytu (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Dla dystrybucji innych niż antiX/MX, użyj trybu obrazu (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="689"/>
        <source>Percent of USB-device to use:</source>
        <translation>Procent urządzenia USB do wykorzystania:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>Label ext partition:</source>
        <translation>Etykieta partycji ext:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Nie uruchamiaj poleceń, które wpływają na urządzenie USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Dry run (no change to system)</source>
        <translation>Przebieg próbny (bez zmian w systemie)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>klonuj z zamontowanego live-usb lub pliku iso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="757"/>
        <source>Clone an existing live system</source>
        <translation>Klonuj istniejący system live</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Ustawienie rozruchu z zaszyfrowanej partycji spowoduje wyświetlenie prośby o podanie hasła przy pierwszym uruchomieniu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="767"/>
        <source>Encrypt</source>
        <translation>Szyfruj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="774"/>
        <source>Clone running live system</source>
        <translation>Klonuj uruchomiony system live</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Confirmation</source>
        <translation>Potwierdzenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="105"/>
        <location filename="../mainwindow.cpp" line="286"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Failure</source>
        <translation>Niepowodzenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="105"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Źródło i miejsce docelowe znajdują się na tym samym urządzeniu, proszę wybierz ponownie.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Zapisywanie %1 przy użyciu polecenia &quot;dd&quot; do /dev/%2,

Poczekaj, aż proces się zakończy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Success</source>
        <translation>Sukces </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>LiveUSB creation successful!</source>
        <translation>Tworzenie LiveUSB zakończyło się sukcesem!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Wystąpił błąd podczas tworzenia LiveUSB.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>Please select a USB device to write to</source>
        <translation>Wybierz urządzenie USB, którego chcesz użyć do zapisu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>clone</source>
        <translation>klonuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program do tworzenia live-usb z pliku iso, z innego live-usb, z live-cd/dvd lub z uruchomionego systemu live.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="382"/>
        <source>%1 License</source>
        <translation>%1 Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>%1 Help</source>
        <translation>%1 Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Wybierz plik ISO, który chcesz zapisać na dysku USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>Select Source Directory</source>
        <translation>Wybierz katalog źródłowy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Nie można znaleźć pliku %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>Hide advanced options</source>
        <translation>Ukryj opcje zaawansowane</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>Select Source</source>
        <translation>Wybierz źródło</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>Select ISO file</source>
        <translation>Wybierz plik ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="577"/>
        <source>Could not find a log file at: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="31"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <location filename="../about.cpp" line="42"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Błąd</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Musisz uruchomić ten program jako administrator. </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation type="unfinished">Program do tworzenia live-usb z pliku iso, z innego live-usb, z live-cd/dvd lub z uruchomionego systemu live.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Name of .iso file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>[filename]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Error</source>
        <translation type="unfinished">Błąd</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
